Example project for the Line Follower robot.

Dependencies:   PM2_Libary Eigen

Revision:
23:26b3a25fc637
Parent:
22:f9370f71d17d
Child:
24:86f1a63e35a0
--- a/main.cpp	Wed Mar 02 17:20:10 2022 +0000
+++ b/main.cpp	Mon Mar 14 08:31:15 2022 +0000
@@ -56,7 +56,6 @@
 /* create servo objects */
 Servo servo_S1(PB_2);
 Servo servo_S2(PC_8);
-// Servo servo_S3(PC_6); // PC_6 is used for ultra sonic sensor below
 int servo_position_S1_mus = 0;
 int servo_position_S2_mus = 0;
 int servo_period_mus = 20000;
@@ -67,8 +66,8 @@
 // Groove Ultrasonic Ranger V2.0
 // https://ch.rs-online.com/web/p/entwicklungstools-sensorik/1743238/?cm_mmc=CH-PLA-DS3A-_-google-_-CSS_CH_DE_Raspberry_Pi_%26_Arduino_und_Entwicklungstools_Whoop-_-(CH:Whoop!)+Entwicklungstools+Sensorik-_-1743238&matchtype=&pla-306637898829&gclid=Cj0KCQjwpdqDBhCSARIsAEUJ0hOLQOOaw_2-Ob03u4YGwXthQPeSyjaazFqNuMkTIT8Ie18B1pD7P9AaAn18EALw_wcB&gclsrc=aw.ds
 /* create range finder object (ultra sonic distance sensor) */
-// RangeFinder range_finder(PC_6, 5782.0f, 0.02f, 17500); // 1/loop_period_ms = 20 Hz parametrization
-RangeFinder range_finder(PB_6, 5782.0f, 0.02f,  7000); // 1/loop_period_ms = 50 Hz parametrization
+// RangeFinder range_finder(PB_12, 5782.0f, 0.02f, 17500); // 1/loop_period_ms = 20 Hz parametrization
+RangeFinder range_finder(PB_12, 5782.0f, 0.02f,  7000); // 1/loop_period_ms = 50 Hz parametrization
 float       dist_us_sensor = 0.0f;
 
 
@@ -77,7 +76,7 @@
 // LSM9DS1 imu(PC_9, PA_8); // if you want to be able to use the imu you need to #include "LSM9DS1_i2c.h"
 
 int main()
-{    
+{
     /* attach button fall and rise functions */
     user_button.fall(&button_fall);
     user_button.rise(&button_rise);